@@ -1,45 +1,12 @@
-# ABSTRACT: a place to store captured Dancer logs
-
 package Dancer::Logger::Capture::Trap;
-{
-    $Dancer::Logger::Capture::Trap::VERSION = '1.9999_02';
-}
-use Moo;
-use Dancer::Core::Types;
 
-has storage => (
-    is      => 'rw',
-    isa     => ArrayRef,
-    default => sub { [] },
-);
+use base 'Dancer::Object';
 
-sub store {
-    my ($self, $level, $message) = @_;
-    push @{$self->storage}, {level => $level, message => $message};
-}
-
-sub read {
-    my $self = shift;
-
-    my $logs = $self->storage;
-    $self->storage([]);
-    return $logs;
-}
-
-1;
-
-__END__
-
-=pod
 
 =head1 NAME
 
 Dancer::Logger::Capture::Trap - a place to store captured Dancer logs
 
-=head1 VERSION
-
-version 1.9999_02
-
 =head1 SYNOPSIS
 
     my $trap = Dancer::Logger::Capture::Trap->new;
@@ -61,6 +28,22 @@ L<Dancer::Logger::Capture>.
 
 Stores a log $message and its $level.
 
+=cut
+
+__PACKAGE__->attributes( "_storage" );
+
+sub init {
+    my $self = shift;
+    $self->_storage([]) unless $self->_storage;
+}
+
+sub store {
+    my($self, $level, $message) = @_;
+
+    push @{$self->_storage}, { level => $level, message => $message };
+}
+
+
 =head3 read
 
     my $logs = $trap->read;
@@ -73,19 +56,21 @@ For example...
      { level => "error",   message => "You fail forever" }
     ];
 
+=cut
+
+sub read {
+    my $self = shift;
+
+    my $logs = $self->_storage;
+    $self->_storage([]);
+    return $logs;
+}
+
+
 =head1 SEE ALSO
 
 L<Dancer::Logger::Capture>
 
-=head1 AUTHOR
-
-Dancer Core Developers
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 by Alexis Sukrieh.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
+
+1;
